@@ -1,6 +1,6 @@
 from .db import sql_to_dictionary
 from .base import Models
-from .users import Users
+from .users import Users # for order.lister
 from .reservations import Reservations, ReservationModelDecorator
 
 class OrderModelDecorator:
@@ -34,7 +34,7 @@ class Orders(Models, ReservationModelDecorator):
         self.date_placed = db_data["date_placed"]
         self.is_online_pay = db_data["is_online_pay"]
         self._is_dropoff_scheduled = db_data["is_dropoff_sched"]
-        self._is_pickup_scheduled = db_data["is_pick_sched"]
+        self._is_pickup_scheduled = db_data["is_pickup_sched"]
         self._lister_id = db_data["lister_id"]
         #reservation
         self._res_date_start = db_data["res_date_start"]
@@ -47,8 +47,8 @@ class Orders(Models, ReservationModelDecorator):
         """Get the true end date for the order, extensions considered."""
         extensions = self.extensions
         if extensions:
-            extensions.sort(key = lambda ext: ext.res_date_end)
-            self._ext_date_end = extensions[-1].res_date_end
+            extensions.sort(key = lambda ext: ext._res_date_end)
+            self._ext_date_end = extensions[-1]._res_date_end
         else:
             self._ext_date_end = self._res_date_end
         return self._ext_date_end
@@ -63,7 +63,7 @@ class Orders(Models, ReservationModelDecorator):
 
     @is_dropoff_scheduled.setter
     def is_dropoff_scheduled(self, is_dropoff_scheduled):
-        SQL = "UPDATE orders SET is_dropoff_scheduled = %s WHERE id = %s;" # Note: no quotes
+        SQL = "UPDATE orders SET is_dropoff_sched = %s WHERE id = %s;" # Note: no quotes
         data = (is_dropoff_scheduled, self.id)
         Models.database.cursor.execute(SQL, data)
         Models.database.connection.commit()
@@ -75,7 +75,7 @@ class Orders(Models, ReservationModelDecorator):
 
     @is_pickup_scheduled.setter
     def is_pickup_scheduled(self, is_pickup_scheduled):
-        SQL = "UPDATE orders SET is_pickup_scheduled = %s WHERE id = %s;" # Note: no quotes
+        SQL = "UPDATE orders SET is_pickup_sched = %s WHERE id = %s;" # Note: no quotes
         data = (is_pickup_scheduled, self.id)
         Models.database.cursor.execute(SQL, data)
         Models.database.connection.commit()
@@ -91,44 +91,24 @@ class Orders(Models, ReservationModelDecorator):
 
     @classmethod
     def by_pickup(cls, pickup):
-        SQL = "SELECT order_id FROM order_pickups WHERE pickup_date = %s, dt_sched = %s, renter_id = %s;" # Note: no quotes
-        data = (pickup.date_pickup, pickup._dt_sched, pickup._renter_id)
-        cls.database.cursor.execute(SQL, data)
-        db_obj = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone()) #NOTE is this just {"order_id": order_id}?
+        SQL = "SELECT order_id FROM order_pickups WHERE pickup_date = %s AND dt_sched = %s AND renter_id = %s;" # Note: no quotes
+        data = (pickup.date_pickup, pickup.dt_sched, pickup.renter_id)
+        Models.database.cursor.execute(SQL, data)
+        db_obj = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone()) #NOTE is this just {"order_id": order_id}?
         order = Orders.get(db_obj["order_id"])
         return order
 
     @classmethod
     def by_dropoff(cls, dropoff):
-        SQL = "SELECT order_id FROM order_dropoffs WHERE dropoff_date = %s, dt_sched = %s, renter_id = %s;" # Note: no quotes
-        data = (dropoff.date_dropoff, dropoff._dt_sched, dropoff._renter_id)
-        cls.database.cursor.execute(SQL, data)
-        db_obj = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone()) #NOTE is this just {"order_id": order_id}?
+        SQL = "SELECT order_id FROM order_dropoffs WHERE dropoff_date = %s AND dt_sched = %s AND renter_id = %s;" # Note: no quotes
+        data = (dropoff.date_dropoff, dropoff.dt_sched, dropoff.renter_id)
+        Models.database.cursor.execute(SQL, data)
+        db_obj = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone()) #NOTE is this just {"order_id": order_id}?
         order = Orders.get(db_obj["order_id"])
         return order
 
-    def early_return(self, early_return_reservation):
-        #NOTE: the order also should not have extensions attached to it
-        return_err = "Early returns must be earlier than the current return date."
-        assert early_return_reservation.date_ended < self.res_date_end, return_err
-
-        item_err = "The reservation is not tied to the same object."
-        assert early_return_reservation.item_id == self.item_id, item_err
-
-        renter_err = "The reservation is not tied to the same renter."
-        assert early_return_reservation.renter_id == self.renter_id, renter_err
-
-        SQL = """UPDATE orders
-            SET is_pickup_scheduled = %s, res_date_start = %s, res_date_end = %s,
-            WHERE id = %s;"""
-        data = (
-            False,
-            early_return_reservation.date_started,
-            early_return_reservation.date_ended,
-            self.id
-        )
-        Models.database.cursor.execute(SQL, data)
-        Models.database.connection.commit()
+    def refresh(self):
+        self = Orders.get(self.id)
 
 class Extensions(Models, OrderModelDecorator, ReservationModelDecorator):
 
@@ -154,8 +134,8 @@ class Extensions(Models, OrderModelDecorator, ReservationModelDecorator):
     def get(cls, extension_keys):
         SQL = "SELECT * FROM extensions WHERE order_id = %s AND res_date_end = %s;" # Note: no quotes
         data = (extension_keys['order_id'], extension_keys['res_date_end'])
-        cls.database.cursor.execute(SQL, data)
-        db_obj = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone())
+        Models.database.cursor.execute(SQL, data)
+        db_obj = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone())
         return Extensions(db_obj)
 
     @classmethod
@@ -164,10 +144,10 @@ class Extensions(Models, OrderModelDecorator, ReservationModelDecorator):
 
     @classmethod
     def delete(cls, extension_keys):
-        SQL = "DELETE * FROM extensions WHERE order_id = %s AND res_date_end = %s;"
+        SQL = "DELETE FROM extensions WHERE order_id = %s AND res_date_end = %s;"
         data = (extension_keys['order_id'], extension_keys['res_date_end'])
-        cls.database.cursor.execute(SQL, data)
-        cls.database.connection.commit()
+        Models.database.cursor.execute(SQL, data)
+        Models.database.connection.commit()
 
     def refresh(self):
         extension_keys = {
