@@ -49,13 +49,14 @@ class Reservations(Models):
         self.is_in_cart = db_data["is_in_cart"]
         self._charge = db_data["charge"]
         self._deposit = db_data["deposit"]
+        self._tax = db_data["tax"]
         self.item_id = db_data["item_id"]
         self.renter_id = db_data["renter_id"]
         self.dt_created = db_data["dt_created"]
 
     def print_total(self):
-        """This is how much user must pay = charge + deposit"""
-        return self._charge + self._deposit
+        """This is how much user must pay = charge + deposit + tax"""
+        return self._charge + self._deposit + self._tax
 
     def print_deposit(self):
         return f"${self._deposit:,.2f}"
@@ -63,6 +64,9 @@ class Reservations(Models):
     def print_charge(self):
         return f"${self._charge:,.2f}"
 
+    def print_tax(self):
+        return f"${self._tax:,.2f}"
+
     def length(self):
         return (self.date_started - self.date_ended).days
 
@@ -78,7 +82,7 @@ class Reservations(Models):
     def set(cls, reservation_keys, changes):
         targets = [f"{target} = %s" for target in changes.keys()]
         targets_str = ", ".join(targets)
-        SQL = """
+        SQL = f"""
             UPDATE reservations SET {targets_str}
                 WHERE date_started = %s
                 AND date_ended = %s
@@ -91,8 +95,8 @@ class Reservations(Models):
             reservation_keys['renter_id'],
             reservation_keys['item_id']]
         data = tuple(updates + keys)
-        cls.database.cursor.execute(SQL, data)
-        cls.database.connection.commit()
+        Models.database.cursor.execute(SQL, data)
+        Models.database.connection.commit()
 
     @classmethod
     def get(cls, reservation_keys):
@@ -107,14 +111,14 @@ class Reservations(Models):
             reservation_keys['date_ended'],
             reservation_keys['renter_id'],
             reservation_keys['item_id'])
-        cls.database.cursor.execute(SQL, data)
-        db_reservation = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone())
+        Models.database.cursor.execute(SQL, data)
+        db_reservation = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone())
         return Reservations(db_reservation)
 
     @classmethod
     def delete(cls, reservation_keys):
         SQL = """
-            DELETE * FROM reservations
+            DELETE FROM reservations
                 WHERE date_started = %s
                 AND date_ended = %s
                 AND renter_id = %s
@@ -124,5 +128,5 @@ class Reservations(Models):
             reservation_keys['date_ended'],
             reservation_keys['renter_id'],
             reservation_keys['item_id'])
-        cls.database.cursor.execute(SQL, data)
-        cls.database.connection.commit()
+        Models.database.cursor.execute(SQL, data)
+        Models.database.connection.commit()
