@@ -24,11 +24,11 @@ class Reviews(Models, UserModelDecorator, ItemModelDecorator):
         #get all items in this general location
         SQL = "SELECT * FROM reviews WHERE author_id = %s;" # Note: no quotes
         data = (user.id, )
-        cls.database.cursor.execute(SQL, data)
+        Models.database.cursor.execute(SQL, data)
         reviews = []
-        for query in cls.database.cursor.fetchall():
-            db_review = sql_to_dictionary(cls.database.cursor, query)
-            reviews.append(cls(db_review))
+        for query in Models.database.cursor.fetchall():
+            db_review = sql_to_dictionary(Models.database.cursor, query)
+            reviews.append(Reviews(db_review))
         return reviews
 
     @classmethod
@@ -36,11 +36,11 @@ class Reviews(Models, UserModelDecorator, ItemModelDecorator):
         #get all items in this general location
         SQL = "SELECT * FROM reviews WHERE item_id = %s;" # Note: no quotes
         data = (item.id, )
-        cls.database.cursor.execute(SQL, data)
+        Models.database.cursor.execute(SQL, data)
         reviews = []
-        for query in cls.database.cursor.fetchall():
-            db_review = sql_to_dictionary(cls.database.cursor, query)
-            reviews.append(cls(db_review))
+        for query in Models.database.cursor.fetchall():
+            db_review = sql_to_dictionary(Models.database.cursor, query)
+            reviews.append(Reviews(db_review))
         return reviews
 
 class Testimonials(Models, UserModelDecorator):
@@ -58,9 +58,9 @@ class Testimonials(Models, UserModelDecorator):
     def get(cls, testimonial_keys):
         SQL = "SELECT * FROM testimonials WHERE date_created = %s AND user_id = %s;" # Note: no quotes
         data = (testimonial_keys["date_created"], testimonial_keys["user_id"])
-        cls.database.cursor.execute(SQL, data)
-        db_obj = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone())
-        return cls(db_obj)
+        Models.database.cursor.execute(SQL, data)
+        db_testimonial = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone())
+        return Testimonials(db_testimonial)
 
     @classmethod
     def set(cls):
@@ -68,10 +68,10 @@ class Testimonials(Models, UserModelDecorator):
 
     @classmethod
     def delete(cls, testimonial_keys):
-        SQL = "DELETE * FROM testimonials WHERE date_created = %s AND user_id = %s;" # Note: no quotes
+        SQL = "DELETE FROM testimonials WHERE date_created = %s AND user_id = %s;" # Note: no quotes
         data = (testimonial_keys["date_created"], testimonial_keys["user_id"])
-        cls.database.cursor.execute(SQL, data)
-        cls.database.connection.commit()
+        Models.database.cursor.execute(SQL, data)
+        Models.database.connection.commit()
 
     def refresh(self):
         testimonial_keys = {
@@ -90,11 +90,11 @@ class Tags(Models):
     def by_item(cls, item):
         SQL = "SELECT * FROM tagging WHERE item_id = %s;"
         data = (item.id, )
-        cls.database.cursor.execute(SQL, data)
+        Models.database.cursor.execute(SQL, data)
         tags = []
         db_tags = []
-        for query in cls.database.cursor.fetchall():
-            db_tag_by_item = sql_to_dictionary(cls.database.cursor, query)
+        for query in Models.database.cursor.fetchall():
+            db_tag_by_item = sql_to_dictionary(Models.database.cursor, query)
             db_tags.append(db_tag_by_item)
 
         for db_tag_by_item in db_tags:
@@ -105,8 +105,8 @@ class Tags(Models):
     def get(cls, tag_name):
         SQL = "SELECT * FROM tags WHERE tag_name = %s;" # Note: no quotes
         data = (tag_name, )
-        cls.database.cursor.execute(SQL, data)
-        db_obj = sql_to_dictionary(cls.database.cursor, cls.database.cursor.fetchone())
+        Models.database.cursor.execute(SQL, data)
+        db_obj = sql_to_dictionary(Models.database.cursor, Models.database.cursor.fetchone())
         return Tags(db_obj)
 
     @classmethod
@@ -115,10 +115,10 @@ class Tags(Models):
 
     @classmethod
     def delete(cls, name):
-        SQL = "DELETE * FROM tags WHERE tag_name = %s;" # Note: no quotes
+        SQL = "DELETE FROM tags WHERE tag_name = %s;" # Note: no quotes
         data = (name, )
-        cls.database.cursor.execute(SQL, data)
-        cls.database.connection.commit()
+        Models.database.cursor.execute(SQL, data)
+        Models.database.connection.commit()
 
     def refresh(self):
         self = Tags.get(self.name)
